@@ -21,32 +21,42 @@ and bundles of :abbr:`SWNTs` and :abbr:`MWNTs`.
    `MWNTBundleGenerator` implemented.
 
 .. versionchanged:: 0.2.20
-   `MWNTGenerator` can only generate single MWNT structure data.
-   Use `MWNTBundleGenerator` to generate bundled MWNT structure data.
+   `MWNTGenerator` no longer generates MWNT *bundles*, only *single* MWNTs.
+   To generate bundled MWNT structure data, use the `MWNTBundleGenerator`
+   class.
 
 .. versionadded:: 0.2.8
-   `MWNTGenerator` implemented
+   `MWNTGenerator` implemented.
 
 .. versionadded:: 0.2.6
-   `GrapheneVacancyGenerator` and `NanotubeVacancyGenerator` implemented
+   `GrapheneVacancyGenerator` and `NanotubeVacancyGenerator` implemented.
 
 .. versionadded:: 0.2.4
-   `NanotubeBundleGenerator` implemented
+   `NanotubeBundleGenerator` implemented.
 
 .. seealso:: CLI module :py:mod:`sknano.scripts.nanogen`
 
 Contents
 ========
 
-Classes for creating interactive abstract representation of nanostructures
----------------------------------------------------------------------------
+Classes for creating abstract physical representations of nano-structures
+--------------------------------------------------------------------------
 .. autosummary::
    :toctree: generated/
 
+   Fullerene
    Graphene
    Nanotube
    NanotubeBundle
 
+Classes for generating fullerene structure data
+------------------------------------------------
+.. autosummary::
+   :toctree: generated/
+
+   FullereneGenerator
+   FullereneBravaisLatticeGenerator
+
 Classes for generating graphene structure data
 -----------------------------------------------
 .. autosummary::
@@ -64,9 +74,10 @@ Classes for generating nanotube structure data
    NanotubeBundleGenerator
    MWNTGenerator
    MWNTBundleGenerator
+   TubeGen
 
-Tools for manipulating nano-structures
---------------------------------------
+Classes for generating nano-structure data with vacancies
+----------------------------------------------------------
 .. autosummary::
    :toctree: generated/
 
@@ -81,20 +92,13 @@ Base classes for creating new structure data generators
    StructureGenerator
    VacancyGenerator
 
-Custom exception classes for handling errors
---------------------------------------------
-
-.. autosummary::
-   :toctree: generated/
-
-   StructureGeneratorError
-
 """
 from __future__ import division, print_function, absolute_import
 
 __docformat__ = 'restructuredtext'
 
 from ._defect_generators import *
+from ._fullerene_bravais_lattice_generators import *
 from ._fullerene_generators import *
 from ._fullerenes import *
 from ._graphene_defect_generators import *
