@@ -23,7 +23,7 @@ from ..structure_io import XYZReader, XYZWriter
 from ..tools import plural_word_check
 from ..tools.refdata import CCbond
 
-from ._nanotube import Nanotube
+from ._nanotubes import Nanotube
 
 format_ext = {'gaussian': '.com',
               'gaussian-pbc': '.com',
